class ConnectionError(Exception):
    pass


class BrokenSessionError(Exception):
    pass
